==> doctorlink-design-system-1.0.2.tgz: package/README.md <==
<p align="center">
  <a href="https://material-ui-next.com/" rel="noopener" target="_blank"><img width="200" src="/static/brand.png" alt="Material-UI logo"></a></p>
</p>

<h1 align="center">Doctorlink Design System</h1>

<div align="center">

[React](http://facebook.github.io/react/) components that implement DoctorLink's Design System

</div>

## Installation

DoctorLink Design System is available as an [npm package](https://www.npmjs.com/package/doctorlinkds).

```sh
npm install doctorlinkds
```

## Usage

Here is a quick example to get you started, **it's all you need**:

```jsx
import React from 'react';
import { render } from 'react-dom';
import Button from 'doctorlinkds/Button';

function App() {
  return (
    <Button variant="raised" color="primary">
      Hello World
    </Button>
  );
}

render(<App />, document.querySelector('#app'));
```

Yes, it's really all you need to get started as you can see in this live and interactive demo:

[![Edit Button](https://codesandbox.io/static/img/play-codesandbox.svg)](https://codesandbox.io/s/4j7m47vlm4)

**Bite the bullet and go for v1-beta.**

## Questions

For *how-to* questions and other non-issues,
please use [StackOverflow](http://stackoverflow.com/questions/tagged/material-ui) instead of Github issues.
There is a StackOverflow tag called "material-ui" that you can use to tag your questions.

## Examples

Are you looking for an example project to get started?
[We host some](https://material-ui-next.com/getting-started/example-projects/).

## Documentation

Check out our [documentation website](https://material-ui-next.com/).

## Contributing

We'd greatly appreciate any [contribution](/CONTRIBUTING.md) you make. :)

## Changelog

Recently Updated?
Please read the [changelog](https://github.com/mui-org/material-ui/releases).

## Roadmap

The future plans and high priority features and enhancements can be found in the [ROADMAP.md](https://material-ui-next.com/discover-more/roadmap/) file.

## Thanks

[<img src="https://www.browserstack.com/images/mail/browserstack-logo-footer.png" width="120">](https://www.browserstack.com/)

Thank you to [BrowserStack](https://www.browserstack.com/) for providing the infrastructure that allows us to test in real browsers.

## License

This project is licensed under the terms of the
[MIT license](/LICENSE).

# DoctorLink
### package.json commands
Command|Description
-|-
```docs:dev```      | runs docs in dev mode
```docs:api```      | builds api core and api lab
```docs:api:core```      | builds all components in ./src
```docs:api:lab```      | builds all components in ./packages/material-ui-lab/src
```docs:icons```      | builds logo: `./static/logo.png`
```docs:build```      | production build of docs
```docs:start```      | runs ```next start```
## To do

- [ ] Remove Material UI string references
- [ ] Update `./static/logo.png` and build icons
- [ ] Update icons in components

==> doctorlink-design-system-1.0.14.tgz: package/README.md <==
<p align="center">
  <a href="https://material-ui-next.com/" rel="noopener" target="_blank"><img width="200" src="/static/brand.png" alt="Material-UI logo"></a></p>
</p>

<h1 align="center">Doctorlink Design System</h1>

<div align="center">

[React](http://facebook.github.io/react/) components that implement DoctorLink's Design System

</div>

## Installation

DoctorLink Design System is available as an [npm package](https://www.npmjs.com/package/doctorlink-design-system).

```sh
npm install doctorlink-design-system
```

## Usage

Here is a quick example to get you started, **it's all you need**:

```jsx
import React from 'react';
import { render } from 'react-dom';
import Button from 'doctorlink-design-system/Button';

function App() {
  return (
    <Button variant="raised" color="primary">
      Hello World
    </Button>
  );
}

render(<App />, document.querySelector('#app'));
```

Yes, it's really all you need to get started as you can see in this live and interactive demo:

[![Edit Button](https://codesandbox.io/static/img/play-codesandbox.svg)](https://codesandbox.io/s/4j7m47vlm4)

**Bite the bullet and go for v1-beta.**

## Questions

For *how-to* questions and other non-issues,
please use [StackOverflow](http://stackoverflow.com/questions/tagged/material-ui) instead of Github issues.
There is a StackOverflow tag called "material-ui" that you can use to tag your questions.

## Examples

Are you looking for an example project to get started?
[We host some](https://material-ui-next.com/getting-started/example-projects/).

## Documentation

Check out our [documentation website](https://material-ui-next.com/).

## Contributing

We'd greatly appreciate any [contribution](/CONTRIBUTING.md) you make. :)

## Changelog

Recently Updated?
Please read the [changelog](https://github.com/mui-org/material-ui/releases).

## Roadmap

The future plans and high priority features and enhancements can be found in the [ROADMAP.md](https://material-ui-next.com/discover-more/roadmap/) file.

## Thanks

[<img src="https://www.browserstack.com/images/mail/browserstack-logo-footer.png" width="120">](https://www.browserstack.com/)

Thank you to [BrowserStack](https://www.browserstack.com/) for providing the infrastructure that allows us to test in real browsers.

## License

This project is licensed under the terms of the
[MIT license](/LICENSE).

# DoctorLink
### package.json commands
Command|Description
-|-
```docs:dev```      | runs docs in dev mode
```docs:api```      | builds api core and api lab
```docs:api:core```      | builds all components in ./src
```docs:api:lab```      | builds all components in ./packages/material-ui-lab/src
```docs:icons```      | builds logo: `./static/logo.png`
```docs:build```      | production build of docs
```docs:start```      | runs ```next start```
## To do

- [ ] Remove Material UI string references
- [ ] Update `./static/logo.png` and build icons
- [ ] Update icons in components
